@@ -1,5 +1,5 @@
 leaflet <-
-function(data, dest, title, size, base.map="osm", center, zoom, style, popup, controls="all", incl.data=FALSE, overwrite=TRUE) {	
+function(data, dest, title, size, base.map="osm", center, zoom, style, popup, label, controls="all", incl.data=FALSE, overwrite=TRUE) {	
   
 	# prepare data
 	if(missing(data)) data <- NA
@@ -29,6 +29,8 @@ function(data, dest, title, size, base.map="osm", center, zoom, style, popup, co
 		else {
 			if(length(data)==1) title <- gsub("_", " ", paste(head(strsplit(basename(data), "[.]")[[1]], -1), collapse="_")) else title <- "map"
 		}
+	} else {
+		title <- gsub("/", "", title)
 	}
 	
 	# prepare base map
@@ -44,7 +46,7 @@ function(data, dest, title, size, base.map="osm", center, zoom, style, popup, co
 		} else if(!is(style, "leafletr.style")) stop("Style object not recognized")
 	}
 	if(length(data)>1 && !is.na(style)) if(length(style)<length(data) || !is.list(style)) stop("Number of styles must correspond to number of data files")
-	if(file.exists(file.path(dest, gsub(" ", "_", title))) && !overwrite) stop("Abort - file already exists")
+	if(file.exists(file.path(dest, gsub("[^[:alnum:]!@#&,=+-_()]", "_", title))) && !overwrite) stop("Abort - file already exists")
 	
 	# prepare popup
 	if(!missing(popup)) {
@@ -58,6 +60,12 @@ function(data, dest, title, size, base.map="osm", center, zoom, style, popup, co
 		else multi.prop <- TRUE
 	}
 	
+	# prepare label
+	if(!is.na(data) && !missing(label)) {
+		if(length(data)!=length(label)) stop("Number of labels must correspond to number of data files")
+		label <- lapply(label, function(x) ifelse(x=="", NA, x))
+	}
+	
 	# prepare map parameter
 	if(missing(size)) size <- NA
 	if(missing(center)) center <- NA
@@ -76,16 +84,15 @@ function(data, dest, title, size, base.map="osm", center, zoom, style, popup, co
 		if(any(controls=="layer")) layer.ctrl <- TRUE
 		if(any(controls=="legend")) legend.ctrl <- TRUE
 	}
-	if(layer.ctrl && length(data)>1 && !incl.data) warning("To add data layers to layer control, set 'incl.data=TRUE'", call.=FALSE)
+	# no legend if only one single style layer 
 	if(any(!is.na(style))) if(is(style, "leafletr.style")) if(!is(style, "graduated.style") && !is(style, "categorized.style")) legend.ctrl <- FALSE
 	
 	# prepare file path
-	dir.create(file.path(dest, gsub(" ", "_", title)), showWarnings=FALSE)
+	dir.create(file.path(dest, gsub("[^[:alnum:]!@#&,=+-_()]", "_", title)), showWarnings=FALSE)
 	if(any(!is.na(data)) && !incl.data) {
-		for(n in 1:length(data)) file.copy(data[[n]], file.path(dest, gsub(" ", "_", title)), overwrite=overwrite)
+		for(n in 1:length(data)) file.copy(data[[n]], file.path(dest, gsub("[^[:alnum:]!@#&,=+-_()]", "_", title)), overwrite=overwrite)
 	}
-	filePath <- file.path(dest, gsub(" ", "_", title), paste0(gsub(" ", "_", title), ".html"))
-	
+	filePath <- file.path(dest, gsub("[^[:alnum:]!@#&,=+-_()]", "_", title), paste0(gsub("[^[:alnum:]!@#&,=+-_()]", "_", title), ".html"))
 	# brew
 	brew(system.file("templates/main.brew", package="leafletR"), filePath) 
 	
