@@ -1,15 +1,17 @@
 toGeoJSON <-
 function(data, name, dest, lat.lon, overwrite=TRUE) {
+	# prepare
 	if(missing(data)) stop("'data' is mandatory")
 	if(missing(dest)) dest <- getwd()
 	dest <- gsub("\\\\", "/", dest)
 	if(substr(dest, nchar(dest), nchar(dest))=="/") dest <- substr(dest, 1, nchar(dest)-1)
 	path <- NULL
 	
-	if(is.data.frame(data)) {
+	# identify type of data and pass to internal functions
+	if(is(data, "data.frame")) {
 		if(missing(name)) name <- deparse(substitute(data))
 		name <- gsub(" ", "_", name)
-		if(missing(lat.lon)) lat.lon <- c(1,2)
+		if(missing(lat.lon)) lat.lon <- NULL
 		path <- dfToGeoJSON(data, name, dest, lat.lon, overwrite)
 	} else if(class(data)=="character") {
 		if(missing(name)) name <- paste(head(strsplit(tail(strsplit(data, "/")[[1]], 1), "[.]")[[1]], -1), collapse=".")
